@@ -1,10 +1,11 @@
 # coding: utf-8
 
 # DJANGO IMPORTS
-try:
-    from django.conf.urls.defaults import *  
-except ImportError:
-    from django.conf.urls import *
+try: 
+    from django.conf.urls import url, patterns
+except ImportError: 
+    # for Django version less then 1.4
+    from django.conf.urls.defaults import url, patterns
 
 from django.views.generic.base import TemplateView
 from .views.related import RelatedLookup, M2MLookup, AutocompleteLookup
